from setuptools import find_packages, setup

setup(
    name="neuro-analysis-py",
    version='0.0.1',
    url='https://github.com/ryanharvey1/neuro_py/',
    license='MIT License',
    author='Ryan Harvey',
    author_email='ryanh412@gmail.com',
    description='Analysis of neuroelectrophysiology data in Python.',
    install_requires=['numpy>=1.23.0', 
                    'scipy>=1.9.0', 
                    'matplotlib>=1.5.0', 
                    'dill', 
                    'scikit-learn',
                    'pandas>=1.5.0',
                    'numba>=0.56.0',
                    'pillow>=9.3.0',
                    'track_linearization',
                    'pickle',
                    'matplotlib',
                    'tqdm>=4.64.0',
                    'joblib>=1.2.0',
                    'pyfftw',
                    'pycircstat',
                    ],
    dependency_links=['https://github.com/ryanharvey1/nelpy'],
    keywords = "electrophysiology neuroscience data analysis",
    include_package_data=True,
    platforms='any',
    packages=find_packages(),
)
